.. Bowtie documentation master file, created by
   sphinx-quickstart on Fri Aug 19 23:07:25 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Layout
======

The Layout class defines the structure of the application:
how things are laid out, subscribing listeners to events, and building the application.

.. autoclass:: bowtie.Layout
    :members:
    :undoc-members:
